==> change_labels-1.3.3.tar.gz: change_labels/src/EventSubscriber/ChangeFieldLabelSubscriber.php <==
<?php

namespace Drupal\change_labels\EventSubscriber;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;
use Drupal\Core\Security\TrustedCallbackInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\field_event_dispatcher\Event\Field\FieldWidgetThirdPartySettingsFormEvent;
use Drupal\field_event_dispatcher\Event\Field\WidgetCompleteFormAlterEvent;
use Drupal\field_event_dispatcher\FieldHookEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Change labels event subscriber.
 */
class ChangeFieldLabelSubscriber implements EventSubscriberInterface, TrustedCallbackInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      FieldHookEvents::FIELD_WIDGET_THIRD_PARTY_SETTINGS_FORM => ['addSettings'],
      FieldHookEvents::WIDGET_COMPLETE_FORM_ALTER => ['alterForm'],
    ];
  }

  /**
   * Event handler for the third party settings of a widget.
   *
   * @param \Drupal\field_event_dispatcher\Event\Field\FieldWidgetThirdPartySettingsFormEvent $event
   *   Triggering event.
   */
  public function addSettings(FieldWidgetThirdPartySettingsFormEvent $event) {
    $element = [];
    $element['field_label_overwrite'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Overwrite field label'),
      '#description' => $this->t('Enter &ltnolabel&gt; to remove the label.'),
      '#default_value' => $event->getPlugin()->getThirdPartySetting('change_labels', 'field_label_overwrite'),
    ];
    $event->addElements('change_labels', $element);
  }

  /**
   * Event handler for altering a widget.
   *
   * @param \Drupal\field_event_dispatcher\Event\Field\WidgetCompleteFormAlterEvent $event
   *   Triggering event.
   */
  public function alterForm(WidgetCompleteFormAlterEvent $event) {
    $setting = $event->getContext()['widget']->getThirdPartySetting('change_labels', 'field_label_overwrite');
    if ($setting) {
      $elements = &$event->getElements();
      $this->setNewLabel($elements, $setting);
      foreach (Element::children($elements) as $child) {
        $this->setNewLabel($elements[$child], $setting);
      }
    }
  }

  /**
   * Apply the label setting to an element.
   */
  protected function setNewLabel(&$element, $setting) {
    foreach (Element::children($element) as $child) {
      $this->setNewLabel($element[$child], $setting);
    }
    if ($setting === '<nolabel>') {
      $element['#title_display'] = 'invisible';

      // Special case for datetime.
      if (isset($element['#type']) && $element['#type'] === 'datetime') {
        $element['#title'] = '';
      }

      if ($this->avoidProcessing($element)) {
        return;
      }
      $processCallback = static::class . '::processChangeFieldLabel';
      // Avoid adding the callback more than once.
      if (isset($element['#process']) && in_array($processCallback, $element['#process'])) {
        return;
      }
      $element['#process'][] = $processCallback;
      return;
    }
    $element['#title'] = $setting;
  }

  /**
   * Wether a "#process" callback shold be added to the element or not.
   *
   * @param array $element
   *   Render array.
   */
  protected function avoidProcessing($element) : bool {
    $types = ['address', 'datetime'];
    if (isset($element['#type']) && in_array($element['#type'], $types)) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * Process callback to add a pre_render after the ones added by the theme.
   */
  public static function processChangeFieldLabel($element, FormStateInterface $form_state, $form) : array {
    $element['#pre_render'][] = [
      static::class,
      'overwriteLabel',
    ];
    return $element;
  }

  /**
   * Process callback to hide label when there is a details element.
   *
   * For example single file widgets.
   */
  public static function overwriteLabel($element) {
    if (isset($element['#theme_wrappers']['details'])) {
      $element['#theme_wrappers']['details']['#summary_attributes']['class'][] = 'visually-hidden';
    }

    // Case for the details wrapper of the address field.
    if (isset($element['#type']) && $element['#type'] === 'details') {
      $element['#summary_attributes']['class'][] = 'visually-hidden';
    }
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks() {
    return [
      'overwriteLabel',
    ];
  }

}

==> change_labels-1.3.4.tar.gz: change_labels/src/EventSubscriber/ChangeFieldLabelSubscriber.php <==
<?php

namespace Drupal\change_labels\EventSubscriber;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;
use Drupal\Core\Security\TrustedCallbackInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\field_event_dispatcher\Event\Field\FieldWidgetThirdPartySettingsFormEvent;
use Drupal\field_event_dispatcher\Event\Field\WidgetCompleteFormAlterEvent;
use Drupal\field_event_dispatcher\FieldHookEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Change labels event subscriber.
 */
class ChangeFieldLabelSubscriber implements EventSubscriberInterface, TrustedCallbackInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      FieldHookEvents::FIELD_WIDGET_THIRD_PARTY_SETTINGS_FORM => ['addSettings'],
      FieldHookEvents::WIDGET_COMPLETE_FORM_ALTER => ['alterForm'],
    ];
  }

  /**
   * Event handler for the third party settings of a widget.
   *
   * @param \Drupal\field_event_dispatcher\Event\Field\FieldWidgetThirdPartySettingsFormEvent $event
   *   Triggering event.
   */
  public function addSettings(FieldWidgetThirdPartySettingsFormEvent $event) {
    $element = [];
    $element['field_label_overwrite'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Overwrite field label'),
      '#description' => $this->t('Enter &ltnolabel&gt; to remove the label.'),
      '#default_value' => $event->getPlugin()->getThirdPartySetting('change_labels', 'field_label_overwrite'),
    ];
    $event->addElements('change_labels', $element);
  }

  /**
   * Event handler for altering a widget.
   *
   * @param \Drupal\field_event_dispatcher\Event\Field\WidgetCompleteFormAlterEvent $event
   *   Triggering event.
   */
  public function alterForm(WidgetCompleteFormAlterEvent $event) {
    $setting = $event->getContext()['widget']->getThirdPartySetting('change_labels', 'field_label_overwrite');
    if ($setting) {
      $elements = &$event->getElements();
      $this->setNewLabel($elements, $setting);
      foreach (Element::children($elements) as $child) {
        $this->setNewLabel($elements[$child], $setting);
      }
    }
  }

  /**
   * Apply the label setting to an element.
   */
  protected function setNewLabel(&$element, $setting) {
    foreach (Element::children($element) as $child) {
      $this->setNewLabel($element[$child], $setting);
    }
    if ($setting === '<nolabel>') {
      $element['#title_display'] = 'invisible';

      // Special case for datetime.
      if (isset($element['#type']) && $element['#type'] === 'datetime') {
        $element['#title'] = '';
      }

      if ($this->avoidProcessing($element)) {
        return;
      }
      $processCallback = static::class . '::processChangeFieldLabel';
      // Avoid adding the callback more than once.
      if (isset($element['#process']) && in_array($processCallback, $element['#process'])) {
        return;
      }
      $element['#process'][] = $processCallback;
      return;
    }
    $element['#title'] = $setting;
  }

  /**
   * Wether a "#process" callback shold be added to the element or not.
   *
   * @param array $element
   *   Render array.
   */
  protected function avoidProcessing($element) : bool {
    $types = ['address', 'datetime'];
    if (isset($element['#type']) && in_array($element['#type'], $types)) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * Process callback to add a pre_render after the ones added by the theme.
   */
  public static function processChangeFieldLabel($element, FormStateInterface $form_state, $form) : array {
    $element['#pre_render'][] = [
      static::class,
      'overwriteLabel',
    ];
    return $element;
  }

  /**
   * Process callback to hide label when there is a details element.
   *
   * For example single file widgets.
   */
  public static function overwriteLabel($element) {
    if (isset($element['#theme_wrappers']['details'])) {
      $element['#theme_wrappers']['details']['#summary_attributes']['class'][] = 'visually-hidden';
    }

    // Case for the details wrapper of the address field.
    if (isset($element['#type']) && $element['#type'] === 'details') {
      $element['#summary_attributes']['class'][] = 'visually-hidden';
    }
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks() {
    return [
      'overwriteLabel',
    ];
  }

}
